/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/

/* Include FreeRTOS APIs and defines */
#include <FreeRTOS.h>
#include <task.h>
#include <queue.h>
#include <semphr.h>
#include <event_groups.h>

/* Include PSoC system and component APIs and defines */
#include <project.h>

/* Include application function declarations and defines */
#include "GLCD_Task.h"
#include "fontArial10X13.h"
#include "Galaxy_bmp.h"
#include "GalaxyMain_bmp.h"

//-----------------------------------------------------------------------------
//  Defines
//-----------------------------------------------------------------------------
#define GLCD_X_BYTES 	(GLCD_NUMCONTROLLERX*GLCD_MAXADDRESS)
#define GLCD_Y_BYTES 	(GLCD_NUMCONTROLLERY*GLCD_MAXPAGE)

//-----------------------------------------------------------------------------
//  Locals
//-----------------------------------------------------------------------------
uint8 CYXDATA u8GLCDInverted=GLCD_DISP_NORMAL;

// from MJK: pixel level bit masks for display
// this array is setup to map the order
// of bits in a byte to the vertical order
// of bits at the LCD controller
// TODO: use somekind of (1<<n) macro

uint8 CYXDATA u8GLCDMaskArray[8] =
         {0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x80};

uint8 CYXDATA u8GLCDBuf[GLCD_Y_BYTES][GLCD_X_BYTES];

uint8 CYXDATA u8GLCDPages[24] = 	
{								
	//  E(1=stop),  D/I(1=Data),  CS2,  CS1  
	//GLCD_ON 0x3F  ,  
	//START0 0xC0 , 
	//SET_PAGE 0xB8,  
	//SET_ADDRES 0x40
	0x3F,	//  Turn on the display at 0, rest can be any (0x00)
	0xB8,	//SET_PAGE 0                   	
	0x40,	//SET_ADDRES 0                       		
	0x00,	//Page 1 (3)
	0xB9,	//SET_PAGE 1  
	0x40,
	0x00,	//SET_PAGE 2 (6)
	0xBA,	//SET_PAGE 2  
	0x40,
	0x00,	//SET_PAGE 3 (9)
	0xBB,	//SET_PAGE 3  
	0x40,
	0x00,	//SET_PAGE 4 (12)
	0xBC,	//SET_PAGE 4  
	0x40,
	0x00,	//SET_PAGE 5 (15)
	0xBD,	//SET_PAGE 5  
	0x40,
	0x00,	//SET_PAGE 6 (18)
	0xBE,	//SET_PAGE 6  
	0x40,
	0x00,	//SET_PAGE 7 (21)
	0xBF,	//SET_PAGE 7  
	0x40
};


uint8  GLCD_DMA_Chan; 

// The DMA Transaction Descriptor (TD)
uint8  GLCD_DMA_TD[17];


volatile unsigned char u8GLCDDMAIntCount=0;

/*************************************************************
* Mutex Defination
*************************************************************/
SemaphoreHandle_t xMutexGLCDBuff;

/*************************************************************
 * Task Priority 
 ************************************************************/

// Define CANRxMBox Task Priority
#define vGLCD_Task_PRIORITY				( 2 )

/* Bit Position for Reqeusting to update GLCD for GLCD_Task Notification */
#define GLCDReqUpdate_event				( ( uint32_t ) 1 << 0 )

/* Bit Position for Status of Update Done GLCD for GLCD_Task Notification*/
#define GLCDUpdateDone_event			( ( uint32_t ) 1 << 1 )

TaskHandle_t xGLCD_TaskHandle,xGLCD_GEMain_TaskHandle;

// Function Prototypes

/* Used for vGLCD Task */
void vGLCD_Task ( void *pvParameters );

/*************************************************************
 * Task Priority 
 ************************************************************/

// Define CANRxMBox Task Priority
#define vGLCD_GEMain_Task_PRIORITY				( 1 )

// Function Prototypes

/* Used for vGLCDMain Task */
void vGLCD_GEMain_Task ( void *pvParameters );

//-----------------------------------------------------------------------------
//  Prototypes
//-----------------------------------------------------------------------------
static void GLCD_FillBuffer(uint8 u8Pattern);

static void GLCD_Write_Data(unsigned char * pu8pointDataPointer,
            unsigned char u8NoOfColumn,
            unsigned char u8StartingPage,
            unsigned char u8StartingColumn);

static void GLCD_Read_Data(unsigned char * pu8TempRead,
        unsigned char u8NoOfColumn,
        unsigned char u8StartingPage,
        unsigned char u8StartingColumn);

static void GLCD_CharDisp (unsigned char u8Charactor,
        const char * pc8FontFile,
        unsigned char u8Startingline,
        unsigned char u8StartingColumn,
        unsigned char u8BackgroundColor);

static void GLCD_Modify_Buffer(unsigned char * pu8DestiArray,
        unsigned char * pu8SourceArray,
        unsigned char u8NoOfColumn,
        unsigned char u8Shiftbits);

static void GLCD_Modify_Buffer_Lastline(unsigned char * pu8DestiArray,
        unsigned char * pu8SourceArray,
        unsigned char u8NoOfColumn,
        unsigned char u8Shiftbits);


CY_ISR_PROTO( vGLCD_DMA_ISR );

/*********************************************************************
vCreateGLCDTask

This routing calls to create GLCD Task

Parameters:		None

Return:			None
*********************************************************************/
void vCreateGLCDTask ( void )
{
	portBASE_TYPE taskCreated;      /* Return value from xTaskCreate */
	
	uint8 CYXDATA * pu8GLCDBufPoint = &u8GLCDBuf[0][0];
	
	GLCD_DATA_Write(0);
	
	CyPins_ClearPin(GLCDC_EN);
	CyPins_ClearPin(GLCDC_CS1);
	CyPins_ClearPin(GLCDC_CS2);
	CyPins_ClearPin(GLCDC_RS);
	CyPins_ClearPin(GLCDC_RW);

	CyPins_ClearPin(GLCDC_RST);
	CyPins_SetPin(GLCDC_RST);
	
	GLCD_DMA_INT_StartEx(vGLCD_DMA_ISR);
	GLCDPWM_1_Start();
	GLCDPWM_2_Start();
	
	GLCD_UPDATE_Write(0);
	
	//Step 1 DMA Initialisation  PSoC 5
  	GLCD_DMA_Chan = GLCD_DMA_DmaInitialize( 
		GLCD_DMA_BYTES_PER_BURST,
		GLCD_DMA_REQUEST_PER_BURST,
		HI16( pu8GLCDBufPoint ),
		HI16(GLCD_DATA_Control_PTR) );

	//Step 2 TD assignment for channels
	//Allocate the TD for DMA channel
	
	GLCD_DMA_TD[0] =  CyDmaTdAllocate();  
	GLCD_DMA_TD[1] =  CyDmaTdAllocate();
	GLCD_DMA_TD[2] =  CyDmaTdAllocate();
	GLCD_DMA_TD[3] =  CyDmaTdAllocate();
	GLCD_DMA_TD[4] =  CyDmaTdAllocate();  
	GLCD_DMA_TD[5] =  CyDmaTdAllocate();
	GLCD_DMA_TD[6] =  CyDmaTdAllocate();
	GLCD_DMA_TD[7] =  CyDmaTdAllocate();
	GLCD_DMA_TD[8] =  CyDmaTdAllocate(); 
	GLCD_DMA_TD[9] =  CyDmaTdAllocate();
	GLCD_DMA_TD[10] = CyDmaTdAllocate();
	GLCD_DMA_TD[11] = CyDmaTdAllocate();
	GLCD_DMA_TD[12] = CyDmaTdAllocate();  
	GLCD_DMA_TD[13] = CyDmaTdAllocate();
	GLCD_DMA_TD[14] = CyDmaTdAllocate();
	GLCD_DMA_TD[15] = CyDmaTdAllocate();
	GLCD_DMA_TD[16] = CyDmaTdAllocate(); // add this TD to finish the 1024-byte
	
	//Step 3 TD Discription
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[0],       3,  	  GLCD_DMA_TD[1],   	TD_INC_SRC_ADR	); // 3 байта команд
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[1],     128, 	  GLCD_DMA_TD[2],    	TD_INC_SRC_ADR 	); //128 байт данных
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[2],       3,  	  GLCD_DMA_TD[3],   	TD_INC_SRC_ADR	); 
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[3],     128, 	  GLCD_DMA_TD[4],    	TD_INC_SRC_ADR 	); 
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[4],       3,  	  GLCD_DMA_TD[5],   	TD_INC_SRC_ADR	); 
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[5],     128, 	  GLCD_DMA_TD[6],    	TD_INC_SRC_ADR 	); 
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[6],       3,  	  GLCD_DMA_TD[7],   	TD_INC_SRC_ADR	); 
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[7],     128, 	  GLCD_DMA_TD[8],    	TD_INC_SRC_ADR 	); 
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[8],       3,  	  GLCD_DMA_TD[9],   	TD_INC_SRC_ADR	); 
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[9],     128, 	  GLCD_DMA_TD[10],    	TD_INC_SRC_ADR 	);
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[10],      3,  	  GLCD_DMA_TD[11],   	TD_INC_SRC_ADR	); 
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[11],    128, 	  GLCD_DMA_TD[12],    	TD_INC_SRC_ADR 	); 
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[12],      3,  	  GLCD_DMA_TD[13],   	TD_INC_SRC_ADR	); 
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[13],    128, 	  GLCD_DMA_TD[14],    	TD_INC_SRC_ADR 	); 
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[14],      3,  	  GLCD_DMA_TD[15],   	TD_INC_SRC_ADR	);
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[15],    128, 	  GLCD_DMA_TD[16],    	TD_INC_SRC_ADR 	); 
	CyDmaTdSetConfiguration(     GLCD_DMA_TD[16],      1, 	  GLCD_DMA_TD[0],    	TD_INC_SRC_ADR| GLCD_DMA__TD_TERMOUT_EN ); // дадим дорисовать последний байт и выставим  TERMOUT_EN
	
	//Step 4 Address for TD
	//From the table of commands: Address teams (including display, No page, No byte address)
	//address of the 128 bytes of page
   	CyDmaTdSetAddress( GLCD_DMA_TD[0],    LO16((uint32)&u8GLCDPages[0]),   		 	LO16((uint32)GLCD_DATA_Control_PTR) );	
	CyDmaTdSetAddress( GLCD_DMA_TD[1],    LO16((uint32)&pu8GLCDBufPoint[0]),     	LO16((uint32)GLCD_DATA_Control_PTR) );	
	CyDmaTdSetAddress( GLCD_DMA_TD[2],    LO16((uint32)&u8GLCDPages[3]),   		 	LO16((uint32)GLCD_DATA_Control_PTR) );		
	CyDmaTdSetAddress( GLCD_DMA_TD[3],    LO16((uint32)&pu8GLCDBufPoint[128]),   	LO16((uint32)GLCD_DATA_Control_PTR) );		
	CyDmaTdSetAddress( GLCD_DMA_TD[4],    LO16((uint32)&u8GLCDPages[6]),   		 	LO16((uint32)GLCD_DATA_Control_PTR) );		
	CyDmaTdSetAddress( GLCD_DMA_TD[5],    LO16((uint32)&pu8GLCDBufPoint[256]),  	LO16((uint32)GLCD_DATA_Control_PTR) );	
	CyDmaTdSetAddress( GLCD_DMA_TD[6],    LO16((uint32)&u8GLCDPages[9]),   		 	LO16((uint32)GLCD_DATA_Control_PTR) );		
	CyDmaTdSetAddress( GLCD_DMA_TD[7],    LO16((uint32)&pu8GLCDBufPoint[384]),   	LO16((uint32)GLCD_DATA_Control_PTR) );	
	CyDmaTdSetAddress( GLCD_DMA_TD[8],    LO16((uint32)&u8GLCDPages[12]),    		LO16((uint32)GLCD_DATA_Control_PTR) );		
	CyDmaTdSetAddress( GLCD_DMA_TD[9],    LO16((uint32)&pu8GLCDBufPoint[512]),   	LO16((uint32)GLCD_DATA_Control_PTR) );		
	CyDmaTdSetAddress( GLCD_DMA_TD[10],   LO16((uint32)&u8GLCDPages[15]),   	 	LO16((uint32)GLCD_DATA_Control_PTR) );		
	CyDmaTdSetAddress( GLCD_DMA_TD[11],   LO16((uint32)&pu8GLCDBufPoint[640]),   	LO16((uint32)GLCD_DATA_Control_PTR) );	
	CyDmaTdSetAddress( GLCD_DMA_TD[12],   LO16((uint32)&u8GLCDPages[18]),   	 	LO16((uint32)GLCD_DATA_Control_PTR) );		
	CyDmaTdSetAddress( GLCD_DMA_TD[13],   LO16((uint32)&pu8GLCDBufPoint[768]),   	LO16((uint32)GLCD_DATA_Control_PTR) );
  	CyDmaTdSetAddress( GLCD_DMA_TD[14],   LO16((uint32)&u8GLCDPages[21]),   	 	LO16((uint32)GLCD_DATA_Control_PTR) );		
	CyDmaTdSetAddress( GLCD_DMA_TD[15],   LO16((uint32)&pu8GLCDBufPoint[896]),   	LO16((uint32)GLCD_DATA_Control_PTR) );
  	CyDmaTdSetAddress( GLCD_DMA_TD[0],    LO16((uint32)&u8GLCDPages[0]),   		 	LO16((uint32)GLCD_DATA_Control_PTR) );
	
	//Map the TD to the DMA Channel
	CyDmaChSetInitialTd(GLCD_DMA_Chan, GLCD_DMA_TD[0]); 	
	
    CyDmaChEnable(GLCD_DMA_Chan, 1);
	
	/* Create Mutex */
	xMutexGLCDBuff = xSemaphoreCreateMutex();

    if( xMutexGLCDBuff == NULL )
    {
        // The semaphore was not created successfully.
		while(1);
    }
	
	/* Create vGLCD_Task */   
	taskCreated = xTaskCreate(
        vGLCD_Task,
        "vGLCD Task",
        configMINIMAL_STACK_SIZE,
        NO_TASK_ARG,          /* Pass the index as a task argument*/
        vGLCD_Task_PRIORITY,
        &xGLCD_TaskHandle );
    
    if( taskCreated != pdPASS )
    {
        while(1);
    }
	
	/* Create vGLCD_GEMain_Task */   
	taskCreated = xTaskCreate(
        vGLCD_GEMain_Task,
        "vGLCDMain Task",
        (2 * configMINIMAL_STACK_SIZE),
        NO_TASK_ARG,          // Pass the index as a task argument
        vGLCD_GEMain_Task_PRIORITY,
        &xGLCD_GEMain_TaskHandle );
    
    if( taskCreated != pdPASS )
    {
        while(1);
    }
}

/*********************************************************************
vGLCD_Task

This is main task of GLCD

Parameters:	pvParameters
Return:		void
*********************************************************************/

void vGLCD_Task ( void *pvParameters )
{
	/* Just to stop compiler warnings. */
	( void ) pvParameters;
	
	uint32_t ulNotifiedValue=0;
	
	for(;;)
	{
		/* Wait for maximum time for either bit to be requested */
		
		xTaskNotifyWait ( 0 ,
						GLCDReqUpdate_event ,
						&ulNotifiedValue ,
						portMAX_DELAY );
		
		if( ( ulNotifiedValue & GLCDReqUpdate_event ) != 0 )
		{
			ulNotifiedValue = 0;
			
			xSemaphoreTake( xMutexGLCDBuff , portMAX_DELAY );
		
			//start update
			GLCD_UPDATE_Write(1);
			
			while ( ( ulNotifiedValue & GLCDUpdateDone_event ) == 0 )
			{
				xTaskNotifyWait ( 0 ,
							GLCDUpdateDone_event ,
							&ulNotifiedValue ,
							portMAX_DELAY );
			}
			
			ulNotifiedValue = 0;
			
			xSemaphoreGive( xMutexGLCDBuff );
		}
		
	}
}


//-----------------------------------------------------------------------------
//  FUNCTION NAME:	GLCD_Update
//
//  DESCRIPTION:
//
//	Copy buffer-RAM to display-RAM
//
//  ARGUMENTS:
//      top     top line of area to update.         
//		bottom  bottom line of area to update.
//
//  RETURNS:
//     none.
//
//-----------------------------------------------------------------------------
void GLCD_UpdateScreen(void)
{
	/* Try to Check with Mutex */
	xSemaphoreTake( xMutexGLCDBuff , portMAX_DELAY );
	
	/* Generate bit to Request send GLCD Update */
	xTaskNotify( xGLCD_TaskHandle, GLCDReqUpdate_event , eSetBits );
	
	/* Release Mutex */
	xSemaphoreGive( xMutexGLCDBuff );
}

CY_ISR(vGLCD_DMA_ISR)
{
	BaseType_t xHigherPriorityTaskWoken, xResult;

	unsigned long ulMask = 0;
	
	/* xHigherPriorityTaskWoken must be initialised to pdFALSE. */
	xHigherPriorityTaskWoken = pdFALSE;
	
	/* Mask off the other RTOS interrupts to interact with the queue. */
	ulMask = portSET_INTERRUPT_MASK_FROM_ISR();
	
	u8GLCDDMAIntCount++;
	if(u8GLCDDMAIntCount<3)
	{
		GLCD_UPDATE_Write(0);
		GLCD_UPDATE_Write(1);
	}
	else
	{
		GLCD_UPDATE_Write(0);
		u8GLCDDMAIntCount=0;
				
		 /* Unblock the handling task so the task can perform any processing necessitated
		by the interrupt.  xHandlingTask is the task's handle, which was obtained
		when the task was created.  The handling task's notification value
		is bitwise ORed with the interrupt status - ensuring bits that are already
		set are not overwritten. */
		xResult = xTaskNotifyFromISR( xGLCD_TaskHandle,
						GLCDUpdateDone_event,
						eSetBits,
						&xHigherPriorityTaskWoken );

		/* Was the message posted successfully? */
		if( xResult != pdFAIL )
		{
		  /* If xHigherPriorityTaskWoken is now set to pdTRUE then a context
		  switch should be requested.  The macro used is port specific and will
		  be either portYIELD_FROM_ISR() or portEND_SWITCHING_ISR() - refer to
		  the documentation page for the port being used. */
		  portYIELD_FROM_ISR( xHigherPriorityTaskWoken );
		}
	}
	
	portCLEAR_INTERRUPT_MASK_FROM_ISR( ulMask );
	
}

//-----------------------------------------------------------------------------
//  FUNCTION NAME:	GLCD_SetInvert
//
//  DESCRIPTION:
//
//	Sets normal or inverse mode
//
//  ARGUMENTS:
//     mode		{GLCD_MODE_INVERT,GLCD_DISP_NORMAL}
//
//  RETURNS:
//     none.
//
//-----------------------------------------------------------------------------
void GLCD_SetInvert(uint8 u8Mode)
{
	u8GLCDInverted = u8Mode;
}

//-----------------------------------------------------------------------------
//  FUNCTION NAME:	GLCD_FillBuffer
//
//  DESCRIPTION:
//
//	Fills memory buffer with specified pattern
//
//  ARGUMENTS:
//     pattern		
//
//  RETURNS:
//     none.
//
//-----------------------------------------------------------------------------
static void GLCD_FillBuffer(uint8 u8Pattern)
{
	uint16 u16X,u16Y;
	
	/* Try to Check with Mutex */
	xSemaphoreTake( xMutexGLCDBuff , portMAX_DELAY );
	
	for (u16Y=0;u16Y<GLCD_Y_BYTES;u16Y++)
		for (u16X=0;u16X<GLCD_X_BYTES;u16X++) 
			u8GLCDBuf[u16Y][u16X]=u8Pattern;
			
	/* Release Mutex */
	xSemaphoreGive( xMutexGLCDBuff );
}

//-----------------------------------------------------------------------------
//  FUNCTION NAME:	GLCD_ClrScr
//
//  DESCRIPTION:
//
//	Clear memory buffer and optionally flushes to display
//
//  ARGUMENTS:
//     bufferAndDisplay		true to flush display
//
//  RETURNS:
//     none.
//
//-----------------------------------------------------------------------------
void GLCD_ClrScr(uint8 u8BufferAndDisplay)
{
	/* Try to Check with Mutex */
	xSemaphoreTake( xMutexGLCDBuff , portMAX_DELAY );
	
	/* Release Mutex */
	xSemaphoreGive( xMutexGLCDBuff );
	
	GLCD_FillBuffer(0x00);
	if ( u8BufferAndDisplay )
		GLCD_UpdateScreen();
		
	
}

//-----------------------------------------------------------------------------
//  FUNCTION NAME:	GLCD_Dot
//
//  DESCRIPTION:
//
//	Change pixel state in memory buffer
//
//  ARGUMENTS:
//      x     	
//		y		
//		mode	{GLCD_MODE_CLEAR,GLCD_MODE_SET,GLCD_MODE_XOR}
//
//  RETURNS:
//     none.
//
//-----------------------------------------------------------------------------
void GLCD_Dot(uint8 u8X, uint8 u8Y, uint8 u8Mode)
{
	/* Try to Check with Mutex */
	xSemaphoreTake( xMutexGLCDBuff , portMAX_DELAY );
	
	// here 2*1 setup - TODO: for 2*2 setting
	uint8 u8BitNum, u8BitMask, u8YByte;
	
	if ( (u8X<=GLCD_RIGHT) && (u8Y<=GLCD_BOTTOM) )
	{
		u8YByte   = u8Y >> 3; // / 8
		u8BitNum  = u8Y & 0x07;
		u8BitMask = u8GLCDMaskArray[u8BitNum];
		
		switch (u8Mode)
		{
			case GLCD_MODE_SET:
				u8GLCDBuf[u8YByte][u8X] |= u8BitMask;
				break;
				
			case GLCD_MODE_CLEAR:
				u8GLCDBuf[u8YByte][u8X] &= ~u8BitMask;
				break;
				
			case GLCD_MODE_XOR:
				u8GLCDBuf[u8YByte][u8X] ^= u8BitMask;
				break;
				
			default:
				break;
		}
	}
	
	
	/* Release Mutex */
	xSemaphoreGive( xMutexGLCDBuff );
}

//-----------------------------------------------------------------------------
//  FUNCTION NAME:	GLCD_Line
//
//  DESCRIPTION:
//
//	Draws line in memory buffer
//
//  ARGUMENTS:
//      x1     	
//		y1		
//      x2     	
//		y2		
//		mode	{GLCD_MODE_CLEAR,GLCD_MODE_SET,GLCD_MODE_XOR}
//
//  RETURNS:
//     none.
//
//-----------------------------------------------------------------------------
void GLCD_Line(uint8 x1, uint8 y1,
	uint8 x2, uint8 y2, uint8 u8Mode)
{
	uint8 CYXDATA u8GLCDLineIndex0=0;
	uint8 u8Length, u8TempX, u8TempY, u8Y, u8YAlt;
	int16 u16TempCal;
	
	if(x1 == x2)
	{									// vertical line
		// x1|y1 must be the upper point
		if(y1 > y2)
		{
			u8TempX = x1;
			u8TempY = y1;
			x1 = x2;
			y1 = y2;
			x2 = u8TempX;
			y2 = u8TempY;
		}
		
		u8Length = y2-y1;
		
		for(u8GLCDLineIndex0=0; u8GLCDLineIndex0<=u8Length; u8GLCDLineIndex0++)
		{
			GLCD_Dot(x1, y1+u8GLCDLineIndex0, u8Mode);
		}
	}
	
	else if(y1 == y2)
	{							
		// horizontal line
		// x1|y1 must be the left point
		if(x1 > x2) 
		{
			u8TempX = x1;
			u8TempY = y1;
			x1 = x2;
			y1 = y2;
			x2 = u8TempX;
			y2 = u8TempY;
		}
		
		u8Length = x2-x1;
		
		for(u8GLCDLineIndex0=0; u8GLCDLineIndex0<=u8Length; u8GLCDLineIndex0++) 
		{
			GLCD_Dot(x1+u8GLCDLineIndex0, y1, u8Mode);
		}
	} 
	
	else 
	{
		// x1 must be smaller than x2
		if(x1 > x2) 
		{
			u8TempX = x1;
			u8TempY = y1;
			x1 = x2;
			y1 = y2;
			x2 = u8TempX;
			y2 = u8TempY;
		}
		
		if((y2-y1) >= (x2-x1) || (y1-y2) >= (x2-x1)) 
		{	
			// angle larger or equal 45?
			u8Length = x2-x1; // not really the length :)
			
			u16TempCal = ((y2-y1)*200)/u8Length;
			u8YAlt = y1;
			
			for(u8GLCDLineIndex0=0; u8GLCDLineIndex0<=u8Length; u8GLCDLineIndex0++) 
			{
				u8Y = ((u16TempCal*u8GLCDLineIndex0)/200)+y1;
				
				if((u16TempCal*u8GLCDLineIndex0)%200 >= 100)
					u8Y++;
				else if((u16TempCal*u8GLCDLineIndex0)%200 <= -100)
					u8Y--;
				
				GLCD_Line(x1+u8GLCDLineIndex0, u8YAlt, x1+u8GLCDLineIndex0, u8Y, u8Mode ); 
				
				if(u8Length<=(y2-y1) && y1 < y2)
					u8YAlt = u8Y+1;
				else if(u8Length<=(y1-y2) && y1 > y2)
					u8YAlt = u8Y-1;
				else
					u8YAlt = u8Y;
			}
		} 
		
		else 
		{										// angle smaller 45?
			// y1 must be smaller than y2
			if(y1 > y2) 
			{
				u8TempX = x1;
				u8TempY = y1;
				x1 = x2;
				y1 = y2;
				x2 = u8TempX;
				y2 = u8TempY;
			}
			u8Length = y2-y1;
			u16TempCal = ((x2-x1)*200)/u8Length;
			u8YAlt = x1;
			
			for(u8GLCDLineIndex0=0; u8GLCDLineIndex0<=u8Length; u8GLCDLineIndex0++) 
			{
				u8Y = ((u16TempCal*u8GLCDLineIndex0)/200)+x1;
				
				if((u16TempCal*u8GLCDLineIndex0)%200 >= 100)
					u8Y++;
				else if((u16TempCal*u8GLCDLineIndex0)%200 <= -100)
					u8Y--;
				
				GLCD_Line(u8YAlt, y1+u8GLCDLineIndex0, u8Y, y1+u8GLCDLineIndex0, u8Mode); 
				
				if(u8Length<=(x2-x1) && x1 < x2)
					u8YAlt = u8Y+1;
				else if(u8Length<=(x1-x2) && x1 > x2)
					u8YAlt = u8Y-1;
				else
					u8YAlt = u8Y;
			}
		}
	}
}

//-----------------------------------------------------------------------------
//  FUNCTION NAME:	GLCD_Rect
//
//  DESCRIPTION:
//
//	Draws rectangle in memory buffer
//
//  ARGUMENTS:
//      x     	
//		y		
//      width  	
//		height
//		mode	{GLCD_MODE_CLEAR,GLCD_MODE_SET,GLCD_MODE_XOR}
//
//  RETURNS:
//     none.
//
//-----------------------------------------------------------------------------
void GLCD_Rect(uint8 u8X, uint8 u8Y, uint8 u8Width, uint8 u8Height,
		uint8 u8Mode)
{
	u8Width--;
	u8Height--;
	GLCD_Line(u8X, u8Y, u8X+u8Width, u8Y, u8Mode);		// top
	GLCD_Line(u8X, u8Y, u8X, u8Y+u8Height, u8Mode);	// left
	GLCD_Line(u8X, u8Y+u8Height, u8X+u8Width, u8Y+u8Height, u8Mode);	// bottom
	GLCD_Line(u8X+u8Width, u8Y, u8X+u8Width, u8Y+u8Height, u8Mode);	// right
	
	if(u8Mode == GLCD_MODE_XOR)
	{
		GLCD_Dot(u8X, u8Y, u8Mode);
		GLCD_Dot(u8X+u8Width, u8Y, u8Mode);
		GLCD_Dot(u8X, u8Y+u8Height, u8Mode);
		GLCD_Dot(u8X+u8Width, u8Y+u8Height, u8Mode);
	}
}

//-----------------------------------------------------------------------------
//  FUNCTION NAME:	GLCD_Box
//
//  DESCRIPTION:
//
//	Draws box in memory buffer
//
//  ARGUMENTS:
//      x     
//		y	
//      width  	
//		height	
//		mode	{GLCD_MODE_CLEAR,GLCD_MODE_SET,GLCD_MODE_XOR}
//
//  RETURNS:
//     none.
//
//-----------------------------------------------------------------------------
void GLCD_Box(uint8 u8X, uint8 u8Y, uint8 u8Width, uint8 u8Height,
		uint8 u8Mode) 
{
	uint8 CYXDATA u8GLCDBoxIndex0=0;
	
	if (u8Width!=0 && u8Height!=0)
	{
		u8Width--;
	
		for (u8GLCDBoxIndex0=u8Y;u8GLCDBoxIndex0<u8Y+u8Height;u8GLCDBoxIndex0++) 
			GLCD_Line(u8X, u8GLCDBoxIndex0, u8X+u8Width, u8GLCDBoxIndex0, u8Mode);
	}
}

//-----------------------------------------------------------------------------
//  FUNCTION NAME:	GLCD_Circle
//
//  DESCRIPTION:
//
//	
//  RETURNS:
//     none.
//
//-----------------------------------------------------------------------------
void GLCD_Circle(uint8 u8XCenter, uint8 u8YCenter,
		uint8 u8Radius, uint8 u8Mode)
{
  	int16 u16TSwitch, u16Y, u16X = 0;
  	uint8 u8Dia;

  	u8Dia = u8YCenter - u8XCenter;
  	u16Y = u8Radius;
  	u16TSwitch = 3 - 2 * u8Radius;
  	
	if(u8Mode == GLCD_MODE_XOR)
	{
		GLCD_Dot(u8XCenter + u16X, u8YCenter + u16Y, u8Mode);
    	GLCD_Dot(u8XCenter + u16X, u8YCenter - u16Y, u8Mode);
		GLCD_Dot(u8YCenter + u16Y - u8Dia, u8YCenter + u16X, u8Mode);
		GLCD_Dot(u8YCenter - u16Y - u8Dia, u8YCenter + u16X, u8Mode);
	}
	
  	while (u16X <= u16Y) {
    	GLCD_Dot(u8XCenter + u16X, u8YCenter + u16Y, u8Mode);
    	GLCD_Dot(u8XCenter + u16X, u8YCenter - u16Y, u8Mode);
    	
    	GLCD_Dot(u8XCenter - u16X, u8YCenter + u16Y, u8Mode);
    	GLCD_Dot(u8XCenter - u16X, u8YCenter - u16Y, u8Mode);
    	
    	GLCD_Dot(u8YCenter + u16Y - u8Dia, u8YCenter + u16X, u8Mode);
    	GLCD_Dot(u8YCenter + u16Y - u8Dia, u8YCenter - u16X, u8Mode);
    	
    	GLCD_Dot(u8YCenter - u16Y - u8Dia, u8YCenter + u16X, u8Mode);
    	GLCD_Dot(u8YCenter - u16Y - u8Dia, u8YCenter - u16X, u8Mode);

    	if (u16TSwitch < 0) {
    		u16TSwitch += (4 * u16X + 6);
    	} else {
      		u16TSwitch += (4 * (u16X - u16Y) + 10);
      		u16Y--;
    	}
    	u16X++;
  	}	
}

void GLCD_CharDisp (unsigned char u8Charactor,
        const char * pc8FontFile,
        unsigned char u8Startingline,
        unsigned char u8StartingColumn,
        unsigned char u8BackgroundColor)
{
    unsigned char u8Index1=0,u8Index2=0;
    unsigned char u8FontHight = pc8FontFile[3];
    unsigned char u8FontStartingChar = pc8FontFile[4];
    unsigned char u8FontTotalChar = pc8FontFile[5];
    unsigned char u8CharactorWidth = pc8FontFile[(u8Charactor-u8FontStartingChar)+6]+2;
    unsigned char u8StartingPage;
    unsigned char u8arryTempBuffer[128];
    unsigned char u8arryTempRead[128];

    unsigned char u8NoofBytePerChar=0,u8NoOfPagesPerChar=0;
    unsigned char u8PostShiftBits,u8MaskBit;
    unsigned char u8PreShiftBits;

    unsigned int u16PointToCharData=0;

    u8NoofBytePerChar=u8FontHight/8;
    u8PostShiftBits=u8FontHight%8;
    u8MaskBit=u8PostShiftBits;

    if (u8PostShiftBits != 0)
    {
        u8NoofBytePerChar++;
    }

    u8NoOfPagesPerChar=u8NoofBytePerChar;

    u8StartingPage=u8Startingline/8;
    u8PreShiftBits=u8Startingline%8;

    if (u8PreShiftBits!=0)
    {
        if (u8PostShiftBits==0)
        {
            u8NoOfPagesPerChar++;
        }
        u8PostShiftBits+=u8PreShiftBits;
        if (u8PostShiftBits>7)
        {
            if (u8PostShiftBits>8)
            {
                u8NoOfPagesPerChar++;
            }
            u8PostShiftBits-=8;
        }
    }

    if (u8Charactor>=u8FontStartingChar &&
            u8Charactor<(u8FontStartingChar+u8FontTotalChar))
    {
        for (u8Index2=0;u8Index2<(u8Charactor-u8FontStartingChar);u8Index2++)
        {
            u16PointToCharData=u16PointToCharData+
                    (pc8FontFile[u8Index2+6]*u8NoofBytePerChar);
        }
        u16PointToCharData=u16PointToCharData+6+u8FontTotalChar;
    }

    for (u8Index1=0;u8Index1<u8NoOfPagesPerChar;u8Index1++)
    {
        for (u8Index2=0;u8Index2<u8CharactorWidth;u8Index2++)
        {
            if (u8Index1<u8NoofBytePerChar)
            {
                if (u8Charactor<u8FontStartingChar ||
                        u8Charactor>=(u8FontStartingChar+u8FontTotalChar))
                {
                    u8arryTempBuffer[u8Index2]=(0x55 ^u8BackgroundColor);
                }
                else if (u8CharactorWidth == 0x2)
                {
                    u8arryTempBuffer[u8Index2]=(0x00 ^u8BackgroundColor);
                }
                else
                {
                    if (u8Index2==0 || u8Index2==u8CharactorWidth-1)
                    {
                        u8arryTempBuffer[u8Index2]=(0x00 ^u8BackgroundColor);
                    }
                    else
                    {
                        u8arryTempBuffer[u8Index2]=(pc8FontFile[
                                u16PointToCharData+
                                (u8Index1*(u8CharactorWidth-2))+(u8Index2-1)] ^
                                u8BackgroundColor);
                    }
                }
            }
            else
            {
                u8arryTempBuffer[u8Index2]=0;
            }

            if (u8Index1==(u8NoofBytePerChar-1) && u8MaskBit != 0)
            {
                u8arryTempBuffer[u8Index2]=u8arryTempBuffer[u8Index2]>>(8-(u8MaskBit));
            }
        }

        if (u8PreShiftBits != 0)
        {
            if (u8Index1==0)
            {
                GLCD_Read_Data(&u8arryTempRead[0],u8CharactorWidth,
                        u8StartingPage,u8StartingColumn);
            }
            GLCD_Modify_Buffer(u8arryTempBuffer,u8arryTempRead,
                    u8CharactorWidth,u8PreShiftBits);
        }

        if (u8Index1==(u8NoOfPagesPerChar-1) && u8PostShiftBits != 0)
        {
            GLCD_Read_Data(&u8arryTempRead[0],u8CharactorWidth,
                    u8Index1+u8StartingPage,u8StartingColumn);
            GLCD_Modify_Buffer_Lastline(u8arryTempBuffer,u8arryTempRead,
                    u8CharactorWidth,u8PostShiftBits);
        }

        GLCD_Write_Data(&u8arryTempBuffer[0],u8CharactorWidth,
                u8Index1+u8StartingPage,u8StartingColumn);
    }
}

/* This function is used to display String
 * with decimal point
 * pc8String = pointer to the string
 * pc8FontFile = font file pointer from where data of the font available
 * u8StartingLine = starting line from where data printing is started
 * u8StartingColumn = Starting Column from where data printing is started
 * u8PreviousField = This is special case where previous string or field to be
 *                      cleared or filled with background colour. If do not
 *                      want to use than leave it zero.
 * u8BackgroundColor = back ground colour either of below
 *                      BackgroundColor_Black
 *                      BackgroundColor_White
 *
 * return value =  the actual string printed width
 *                  it may be used next time when printing other value
 *                  at same location.
 */

unsigned char GLCD_String(const char * pc8String,
        const char * pc8FontFile,
        unsigned char u8Startingline,
        unsigned char u8StartingColumn,
        unsigned char u8BackgroundColor)
{
    unsigned char u8Index1=0;
    unsigned char u8Charactor;
    unsigned char u8StringWidth=0;
    unsigned char u8FontStartingChar = pc8FontFile[4];

    while((u8Charactor = pc8String[u8Index1++])!=0)
    {
        GLCD_CharDisp(u8Charactor,&pc8FontFile[0],
                u8Startingline,(u8StartingColumn+u8StringWidth),
                u8BackgroundColor);
        u8StringWidth = u8StringWidth+
                pc8FontFile[(u8Charactor-u8FontStartingChar)+6]+2;
    }

    return u8StringWidth;
}

void GLCD_Modify_Buffer(unsigned char * pu8DestiArray,
        unsigned char * pu8SourceArray,
        unsigned char u8NoOfColumn,
        unsigned char u8Shiftbits)
{
    unsigned int u16Tempdata;
    unsigned char u8Index1;

    for (u8Index1=0;u8Index1<u8NoOfColumn;u8Index1++)
    {
        u16Tempdata=(pu8SourceArray[u8Index1]<<(8-u8Shiftbits)) & 0x00FF;
        u16Tempdata=u16Tempdata | ((pu8DestiArray[u8Index1]<<8) & 0xFF00);
        u16Tempdata=u16Tempdata>>(8-u8Shiftbits);
        pu8SourceArray[u8Index1]=(unsigned char)(u16Tempdata>>8);
        pu8DestiArray[u8Index1]=(unsigned char)(u16Tempdata);
    }
}

void GLCD_Modify_Buffer_Lastline(unsigned char * pu8DestiArray,
        unsigned char * pu8SourceArray,
        unsigned char u8NoOfColumn,
        unsigned char u8Shiftbits)
{
    unsigned int u16Tempdata;
    unsigned char u8Index1;

    for (u8Index1=0;u8Index1<u8NoOfColumn;u8Index1++)
    {
        u16Tempdata=(pu8DestiArray[u8Index1]<<(8-u8Shiftbits)) & 0x00FF;
        u16Tempdata=u16Tempdata |
                (((pu8SourceArray[u8Index1]>>(u8Shiftbits))<<8) & 0xFF00);
        u16Tempdata=u16Tempdata>>(8-u8Shiftbits);
        pu8DestiArray[u8Index1]=(unsigned char)(u16Tempdata);
    }
}

void GLCD_Write_Data(unsigned char * pu8pointDataPointer,
            unsigned char u8NoOfColumn,
            unsigned char u8StartingPage,
            unsigned char u8StartingColumn)
{
	/* Try to Check with Mutex */
	xSemaphoreTake( xMutexGLCDBuff , portMAX_DELAY );
	
	unsigned char u8Index;
    
	for (u8Index=0;u8Index<u8NoOfColumn;u8Index++)
    {
		if ((u8StartingColumn+u8Index)>GLCD_RIGHT)
			break;
		u8GLCDBuf[u8StartingPage][u8StartingColumn+u8Index]
		= pu8pointDataPointer[u8Index];
    }
	
	/* Release Mutex */
	xSemaphoreGive( xMutexGLCDBuff );
}

void GLCD_Read_Data(unsigned char * pu8TempRead,
        unsigned char u8NoOfColumn,
        unsigned char u8StartingPage,
        unsigned char u8StartingColumn)
{
	/* Try to Check with Mutex */
	xSemaphoreTake( xMutexGLCDBuff , portMAX_DELAY );
	
	unsigned char u8Index=0;
    
	for (u8Index=0;u8Index<u8NoOfColumn;u8Index++)
    {
		if ((u8StartingColumn+u8Index)>GLCD_RIGHT)
			break;
        pu8TempRead[u8Index]=
		u8GLCDBuf[u8StartingPage][u8StartingColumn+u8Index];
    }
	
	/* Release Mutex */
	xSemaphoreGive( xMutexGLCDBuff );
}

//-----------------------------------------------------------------------------
//  FUNCTION NAME:	GLCD_BitmapBuffer
//
//  DESCRIPTION:
//
//	Adds full screen bitmap to buffer.
//	Image has to be rotated and bits flipped
//
//	ARGUMENTS:
//		pbitmap
//
//  RETURNS:
//     none.
//
//-----------------------------------------------------------------------------
void GLCD_BitmapFullBuffer(const char * u8pcBitmap,
		unsigned char u8ImageType)
{
	/* Try to Check with Mutex */
	xSemaphoreTake( xMutexGLCDBuff , portMAX_DELAY );
	
	// pin in demopic
	int u8Index0,u8X,u8Y;
	uint16 u16BufferOffset;
	uint16 u8BitMapOffset;
	
	for (u8Index0=0;u8Index0<GLCD_NUMCONTROLLER;u8Index0++) {
		u16BufferOffset = u8Index0 * GLCD_MAXADDRESS;
		for (u8Y=0;u8Y<GLCD_MAXPAGE;u8Y++) {
			u8BitMapOffset = u8Y * GLCD_NUMCONTROLLER * GLCD_MAXADDRESS;
			u8BitMapOffset += u16BufferOffset;
			for (u8X=0;u8X<GLCD_MAXADDRESS;u8X++) {
				u8GLCDBuf[u8Y][u8X+u16BufferOffset]=
				u8pcBitmap[u8BitMapOffset+u8X+2]^ u8ImageType;
			}
		}
	}
	
	/* Release Mutex */
	xSemaphoreGive( xMutexGLCDBuff );
}

void GLCD_Bitmap(const char * pc8PicturePoint,
	unsigned char u8Startingline,
	unsigned char u8StartingColumn,
	unsigned char u8ImageType)
{
    unsigned char u8Index1,u8Index2;
    unsigned char u8NoOfColumn = pc8PicturePoint[0];
    unsigned char u8TempBuffer[128];
    unsigned char u8TempRead[128];
    unsigned char u8PreShiftBits=0,u8PostShiftBits=0;
    unsigned char u8StartingPage;
    unsigned char u8TotalPage=0,u8TotalByte=0;
    unsigned char u8NoOfLine = pc8PicturePoint[1];

    u8TotalByte=u8NoOfLine/8;
    u8PostShiftBits=u8NoOfLine%8;

    if (u8PostShiftBits != 0)
    {
        u8TotalByte++;
    }

    u8TotalPage=u8TotalByte;

    u8StartingPage=u8Startingline/8;
    u8PreShiftBits=u8Startingline%8;

    if (u8PreShiftBits!=0)
    {
        if (u8PostShiftBits==0)
        {
            u8TotalPage++;
        }

        u8PostShiftBits+=u8PreShiftBits;

        if (u8PostShiftBits>7)
        {
            if (u8PostShiftBits>8)
            {
                u8TotalPage++;
            }
            u8PostShiftBits-=8;
        }
    }

    for (u8Index1=0;u8Index1<u8TotalPage;u8Index1++)
    {
        for(u8Index2=0;u8Index2<u8NoOfColumn;u8Index2++)
        {
            if (u8Index1<u8TotalByte)
            {
                u8TempBuffer[u8Index2] =
                        pc8PicturePoint[(u8Index1*u8NoOfColumn)+u8Index2+2]
                        ^ u8ImageType;
            }
            else
                u8TempBuffer[u8Index2]=0;
        }

        if (u8PreShiftBits != 0)
        {
            if (u8Index1==0)
            {
                GLCD_Read_Data(&u8TempRead[0],u8NoOfColumn,
                        u8StartingPage,u8StartingColumn);
            }

            GLCD_Modify_Buffer(u8TempBuffer,u8TempRead,u8NoOfColumn,
                    u8PreShiftBits);
        }

        if (u8Index1==(u8TotalPage-1) && u8PostShiftBits != 0)
        {
            GLCD_Read_Data(&u8TempRead[0],u8NoOfColumn,
                    u8Index1+u8StartingPage,u8StartingColumn);
            GLCD_Modify_Buffer_Lastline(&u8TempBuffer[0],&u8TempRead[0],
                    u8NoOfColumn,u8PostShiftBits);
        }

        GLCD_Write_Data(&u8TempBuffer[0],u8NoOfColumn,u8Index1+u8StartingPage,
                u8StartingColumn);
    }
}

/* This function is used to display Int (16 bit) left justified
 *unsigned int u16Val = value of the variable
 * u8NoOfChar = number of the charactor to be displayed 1 to 5 other wise
 *              the actual charactor in interger is printed.
 * pc8FontFile = font file pointer from where data of the font available
 * u8StartingLine = starting line from where data printing is started
 * u8StartingColumn = Starting Column from where data printing is started
 * u8PreviousField = This is special case where previous string or field to be
 *                      cleared or filled with background colour. If do not
 *                      want to use than leave it zero.
 * u8BackgroundColor = back ground colour either of below
 *                      BackgroundColor_Black
 *                      BackgroundColor_White
 *
 * return value =  the actual string printed width
 *                  it may be used next time when printing other value
 *                  at same location.
 */
unsigned char GLCD_WriteInt(unsigned int u16Val,
	unsigned char u8NoOfChar,
	const char * pc8FontFile,
	unsigned char u8StartingLine,
	unsigned char u8StartingColumn,
	unsigned char u8BackgroundColor)
{
    //string data
    //actually six element containing null charactor for string end
    unsigned char u8StringData[6]={0,0,0,0,0,0};

    unsigned char u8Index1=0,u8Index2=0;

    unsigned char u8StringWidth=0;

    unsigned char u8FontStartingChar = pc8FontFile[4];
    
    u8Index1 = 4;

    while(u16Val)
    {
        u8StringData[u8Index1]=u16Val%10;
        u16Val=u16Val/10;
        u8Index1--;
    }

    u8StringData[0]|=0x30;
    u8StringData[1]|=0x30;
    u8StringData[2]|=0x30;
    u8StringData[3]|=0x30;
    u8StringData[4]|=0x30;

    if(u8NoOfChar>5 || u8NoOfChar == 0)
    {
        while((u8StringData[u8Index2] & 0x0F)==0)
        {
            u8Index2++;
        }
    }
    
    else
    {
        u8Index2=5-u8NoOfChar;
    }
    
    for(u8Index1=u8Index2;u8Index1<5;u8Index1++)
    {
        GLCD_CharDisp(u8StringData[u8Index1],pc8FontFile,u8StartingLine,
                (u8StartingColumn+u8StringWidth),u8BackgroundColor);
        u8StringWidth = u8StringWidth+
                pc8FontFile[(u8StringData[u8Index1]-u8FontStartingChar)+6]+2;
    }
    
    return u8StringWidth;
}

/* This function is used to display Int (16 bit) left justified
 * with decimal point
 *unsigned int u16Val = value of the variable
 * u8NoOfChar = number of the charactor to be displayed 1 to 5 other wise
 *              the actual charactor in interger is printed.
 * u8Dec_point = Location of Decimal Point 0 = lsb point 5 is msb point
 * pc8FontFile = font file pointer from where data of the font available
 * u8StartingLine = starting line from where data printing is started
 * u8StartingColumn = Starting Column from where data printing is started
 * u8PreviousField = This is special case where previous string or field to be
 *                      cleared or filled with background colour. If do not
 *                      want to use than leave it zero.
 * u8BackgroundColor = back ground colour either of below
 *                      BackgroundColor_Black
 *                      BackgroundColor_White
 *
 * return value =  the actual string printed width
 *                  it may be used next time when printing other value
 *                  at same location.
 */
unsigned char GLCD_WriteIntdec(unsigned int u16Val,
	unsigned char u8NoOfChar,
	unsigned char u8Dec_point,
	const char * pc8FontFile,
	unsigned char u8StartingLine,
	unsigned char u8StartingColumn,
	unsigned char u8BackgroundColor)
{
    unsigned char u8StringData[7]={0,0,0,0,0,0,0};
    unsigned char u8Additiona_Zero_Before_Point=0;
    unsigned int u16Index1=5, u16Index2=0;

    unsigned char u8StringWidth=0;

    unsigned char u8FontStartingChar = pc8FontFile[4];

    while(u16Val)
    {
        u8StringData[u16Index1]=u16Val%10;
        u16Val=u16Val/10;
        u16Index1--;
    }

    u8StringData[0]|=0x30;
    u8StringData[1]|=0x30;
    u8StringData[2]|=0x30;
    u8StringData[3]|=0x30;
    u8StringData[4]|=0x30;
    u8StringData[5]|=0x30;

    if(u8NoOfChar>=6 || u8NoOfChar==0)
        while((u8StringData[u16Index2] & 0x0F)==0) u16Index2++;
    else
        u16Index2=6-u8NoOfChar;


    if (u8Dec_point<6)
    {
        for(u16Index1=u16Index2;u16Index1<6-u8Dec_point;u16Index1++)
        {
            u8Additiona_Zero_Before_Point=1;
            GLCD_CharDisp(u8StringData[u16Index1],pc8FontFile,
                    u8StartingLine,(u8StartingColumn+u8StringWidth),
                    u8BackgroundColor);

            u8StringWidth = u8StringWidth+
                    pc8FontFile[(u8StringData[u16Index1]-
                    u8FontStartingChar)+6]+2;
        }
    }

    else
        u16Index1=u16Index2;

    if(u8Additiona_Zero_Before_Point==0)
    {
        GLCD_CharDisp('0',pc8FontFile,u8StartingLine,
                (u8StartingColumn+u8StringWidth),u8BackgroundColor);
        u8StringWidth = u8StringWidth+
                pc8FontFile[('0'-u8FontStartingChar)+6]+2;
    }

    GLCD_CharDisp('.',pc8FontFile,u8StartingLine,
            (u8StartingColumn+u8StringWidth),u8BackgroundColor);
    u8StringWidth = u8StringWidth+
            pc8FontFile[('.'-u8FontStartingChar)+6]+2;

    u8Dec_point=u16Index1;

    for(u16Index1=u8Dec_point;u16Index1<6;u16Index1++)
    {
        GLCD_CharDisp(u8StringData[u16Index1],
                pc8FontFile,u8StartingLine,
                (u8StartingColumn+u8StringWidth),u8BackgroundColor);
        u8StringWidth = u8StringWidth+
                pc8FontFile[(u8StringData[u16Index1]-
                u8FontStartingChar)+6]+2;
    } //for loop end

    return u8StringWidth;
}

/* This function is used to display uint8 into hex charactor left justified
 * u8Val = value of the variable
 * pc8FontFile = font file pointer from where data of the font available
 * u8StartingLine = starting line from where data printing is started
 * u8StartingColumn = Starting Column from where data printing is started
 * u8PreviousField = This is special case where previous string or field to be
 *                      cleared or filled with background colour. If do not
 *                      want to use than leave it zero.
 * u8BackgroundColor = back ground colour either of below
 *                      BackgroundColor_Black
 *                      BackgroundColor_White
 *
 * return value =  the actual string printed width
 *                  it may be used next time when printing other value
 *                  at same location.
 */
unsigned char GLCD_WriteChar_Hex (unsigned char u8Val,
	const char * pc8FontFile,
	unsigned char u8StartingLine,
	unsigned char u8StartingColumn,
	unsigned char u8BackgroundColor)
{
    unsigned char u8TempCalculateValue;
    unsigned char u8StringWidth=0;
    unsigned char u8FontStartingChar = pc8FontFile[4];

    u8TempCalculateValue=((u8Val>>4) & 0x0F);
    u8TempCalculateValue|=0x30;

    if (u8TempCalculateValue > 0x39)
    {
        u8TempCalculateValue=u8TempCalculateValue+7;
    }

    GLCD_CharDisp(u8TempCalculateValue,pc8FontFile,u8StartingLine,
            (u8StartingColumn+u8StringWidth),u8BackgroundColor);
    u8StringWidth = u8StringWidth+
            pc8FontFile[(u8TempCalculateValue-u8FontStartingChar)+6]+2;

    u8TempCalculateValue=(u8Val & 0x0F);
    u8TempCalculateValue|=0x30;

    if (u8TempCalculateValue > 0x39)
    {
        u8TempCalculateValue=u8TempCalculateValue+7;
    }

    GLCD_CharDisp(u8TempCalculateValue,pc8FontFile,u8StartingLine,
            (u8StartingColumn+u8StringWidth),u8BackgroundColor);

    u8StringWidth = u8StringWidth+
            pc8FontFile[(u8TempCalculateValue-u8FontStartingChar)+6]+2;

    return u8StringWidth;
}

/*********************************************************************
vGLCD_GEMain_Task

This is main task of GLCD

Parameters:	pvParameters
Return:		void
*********************************************************************/

// SolCurrCali_Task States
typedef enum
{
	//DoNothing Stae
	glcdDoNothing,
	
	//Display GE Main Pic
	glcdGEMainPic,
	
	//Display Loop Screen
	glcdLoopScreen
	
} GLCDMainState;

/* Define Screen Delay */
#define GLCD_GEMain_mSDelay				( 1000 )
	
/* Define Task Delay in No of Ticks */
#define GLCD_GEMain_Delay					( ( GLCD_GEMain_mSDelay * configTICK_RATE_HZ) / 1000 )

void vGLCD_GEMain_Task ( void *pvParameters )
{
	TickType_t xLastWakeTime; /* used for last tick count store */
	
	TickType_t xTaskDelay = DIReq_TASK_Delay; /* used for the delay between task loop */
	
	GLCDMainState xGLCDGEMainState = glcdGEMainPic;
	
	// Initialise the xLastWakeTime variable with the current time.
    xLastWakeTime = xTaskGetTickCount();
	
	//set circle index
	uint8 CYXDATA u8CircleIndex=0;
	
	//for index
	uint8 CYXDATA u8Index0=0;
	
	unsigned int u16Counter0=0;
	unsigned int u16Field0=0,u16Field1=0,u16Field2=0;
	unsigned char u8ToggleImage=0;
	
	char text2[] = "Galaxy Electronics\0";
	
	/* Just to stop compiler warnings. */
	( void ) pvParameters;
	
	for(;;)
	{
		// Wait for the next cycle.
		vTaskDelayUntil( &xLastWakeTime, xTaskDelay );
		
		switch ( xGLCDGEMainState )
		{
			case glcdGEMainPic:
				GLCD_ClrScr(1);
				
				GLCD_SetInvert(GLCD_DISP_NORMAL);
				//LCD128x64_SetInvert(LCD128x64_DISP_INVERTED);   // Sets normal or inverse mode
				
				GLCD_BitmapFullBuffer(c8GalaxyMain_bmp,GLCD_ImageType_Normal);
				GLCD_UpdateScreen();
				
				GLCD_BitmapFullBuffer(c8GalaxyMain_bmp,GLCD_ImageType_Normal);
				GLCD_UpdateScreen();
				
				u8CircleIndex=4;
				
				while(u8CircleIndex!=0)
				{
					//must be less than or equal to 71
					for(u8Index0=0;u8Index0<71;u8Index0++)
					{
						GLCD_Circle(63, 32, u8Index0, GLCD_MODE_XOR);
						GLCD_UpdateScreen();
					}
					u8CircleIndex--;
					
					vTaskDelay(GLCD_GEMain_Delay);
				}
				
				GLCD_ClrScr(0);
				GLCD_Bitmap(c8Galaxy_bmp,0,88,GLCD_ImageType_Invert);
				GLCD_Box(0, 45, 128, 19, GLCD_MODE_CLEAR);
				
				GLCD_Line(0, 46, 127, 46, GLCD_MODE_XOR);
				GLCD_Line(0, 62, 127, 62, GLCD_MODE_XOR);
				GLCD_Circle(72, 54, 5, GLCD_MODE_XOR);
			    GLCD_Box(86, 50, 15, 10, GLCD_MODE_XOR);	
			    GLCD_Rect(103, 50, 25, 10, GLCD_MODE_XOR);
			    GLCD_Dot(80, 55, GLCD_MODE_XOR);    //   точка
			    GLCD_Dot(83, 55, GLCD_MODE_XOR);    //   точка
			    GLCD_UpdateScreen();   // Copy buffer-RAM to display-RAM
				
				u8Index0=0;
				
				xTaskDelay = GLCD_GEMain_Delay;
				
				xGLCDGEMainState = glcdLoopScreen;
				
				break;
				
			case glcdLoopScreen:
				
				GLCD_Box(0, 0, u16Field0, c8FontArial_10x13Bold[3], GLCD_MODE_CLEAR);
				u16Field0 = GLCD_WriteInt(u16Counter0,5,c8FontArial_10x13Bold,
					0,0,GLCD_Background_White);
				
				GLCD_Box(0, 15, u16Field1, c8FontArial_10x13Bold[3], GLCD_MODE_CLEAR);
				u16Field1 = GLCD_WriteIntdec((u16Counter0/10),4,3,c8FontArial_10x13Bold,
					15,0,GLCD_Background_White);
				
				GLCD_Box(0, 47, u16Field2, c8FontArial_10x13Bold[3], GLCD_MODE_CLEAR);
				u16Field2 = GLCD_WriteChar_Hex((u16Counter0/20),c8FontArial_10x13Bold,
					47,0,GLCD_Background_White);
				
				u16Counter0++;
				if((u16Counter0&0x001F)==0x001F)
				{
					u8ToggleImage=u8ToggleImage^0x01;
					if(u8ToggleImage!=0)
					{
						GLCD_Bitmap(c8Galaxy_bmp,0,88,GLCD_ImageType_Invert);
					}
					else
					{
						GLCD_Bitmap(c8Galaxy_bmp,0,88,GLCD_ImageType_Normal);
					}
				}
				
		        if (u8Index0 < 64) 
		        {
					GLCD_Box(0, 32, u8Index0, 13, GLCD_MODE_CLEAR); 
					GLCD_String(text2,c8FontArial_10x13Bold,32,
						u8Index0,GLCD_Background_White);
					u8Index0++;
		        }
		        else
		        {
					GLCD_Box(127-u8Index0, 32, 127, 13, GLCD_MODE_CLEAR); 
					GLCD_String(text2,c8FontArial_10x13Bold,32,
						127-u8Index0,GLCD_Background_White);
					u8Index0++;
					
					if (u8Index0 > 127)
						u8Index0=0;
		        }
		        GLCD_UpdateScreen();
				
				xTaskDelay = GLCD_TASK_Delay;
				
				break;
				
			case glcdDoNothing:
				xTaskDelay = portMAX_DELAY;
				break;
		}
	}
}

/* [] END OF FILE */

