/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/

#ifndef __GLCD_TASK_H
#define __GLCD_TASK_H

/* Include FreeRTOS APIs and defines */
#include <FreeRTOS.h>
#include <task.h>
#include <queue.h>
#include <event_groups.h>

/* Include PSoC system and component APIs and defines */
#include <project.h>
#include <GenDef.h>
#include <TaskDelay.h>

#define GLCD_DISP_NORMAL	0
#define GLCD_DISP_INVERTED  1

#define GLCD_MODE_CLEAR     0
#define GLCD_MODE_SET       1
#define GLCD_MODE_XOR       2
	
#define GLCD_Background_Black		0xFF
#define GLCD_Background_White       0x00

#define GLCD_ImageType_Invert		0xFF
#define GLCD_ImageType_Normal		0x00
	

#define GLCD_CLEAR_BUFFER   0
#define GLCD_CLEAR_ALL      1
	
#include <GLCD_DMA_dma.h>

#define GLCD_DMA_BYTES_PER_BURST 1	
#define GLCD_DMA_REQUEST_PER_BURST 1

/* display definition */
#define GLCD_NUMCONTROLLER   2
#define GLCD_NUMCONTROLLERX  2
#define GLCD_NUMCONTROLLERY  1

#define GLCD_MAXPAGE 		 8
#define GLCD_MAXADDRESS		 64

#define GLCD_LEFT			0
#define GLCD_TOP			0
#define GLCD_RIGHT			(GLCD_NUMCONTROLLERX*GLCD_MAXADDRESS-1)
#define GLCD_BOTTOM			(GLCD_NUMCONTROLLERY*GLCD_MAXPAGE*8-1)


//-----------------------------------------------------------------------------
//  Prototypes
//-----------------------------------------------------------------------------
void GLCD_Start(void);

void GLCD_SetInvert(uint8 u8Mode);

void GLCD_UpdateScreen(void);

void GLCD_ClrScr(uint8 u8BufferAndDisplay);

void GLCD_Dot(uint8 x, uint8 y, uint8 u8Mode);
#define GLCD_SetDot(x,y) GLCD_Dot(x, y, GLCD_MODE_SET)
#define GLCD_ClearDot(x,y) GLCD_Dot(x, y, GLCD_MODE_CLEAR);

void GLCD_Line(uint8 x1, uint8 y1,
	uint8 x2, uint8 y2, uint8 u8Mode);
void GLCD_Circle(uint8 u8XCenter, uint8 u8YCenter,
		uint8 u8Radius, uint8 u8Mode);
void GLCD_Rect(uint8 x, uint8 y, uint8 u8Width, uint8 u8Height,
		uint8 u8Mode);
void GLCD_Box(uint8 x, uint8 y, uint8 u8Width, uint8 u8Height,
		uint8 u8Mode);

void GLCD_BitmapFullBuffer(const char * u8pcBitmap,
		unsigned char u8ImageType);

void GLCD_Bitmap(const char * pc8PicturePoint,
        unsigned char u8Startingline,
        unsigned char u8StartingColumn,
        unsigned char u8ImageType);


unsigned char GLCD_String(const char * pc8String,
        const char * pc8FontFile,
        unsigned char u8Startingline,
        unsigned char u8StartingColumn,
        unsigned char u8BackgroundColor);

unsigned char GLCD_WriteInt(unsigned int u16Val,
	unsigned char u8NoOfChar,
	const char * pc8FontFile,
	unsigned char u8StartingLine,
	unsigned char u8StartingColumn,
	unsigned char u8BackgroundColor);

unsigned char GLCD_WriteIntdec(unsigned int u16Val,
	unsigned char u8NoOfChar,
	unsigned char u8Dec_point,
	const char * pc8FontFile,
	unsigned char u8StartingLine,
	unsigned char u8StartingColumn,
	unsigned char u8BackgroundColor);

unsigned char GLCD_WriteChar_Hex (unsigned char u8Val,
	const char * pc8FontFile,
	unsigned char u8StartingLine,
	unsigned char u8StartingColumn,
	unsigned char u8BackgroundColor);


void vCreateGLCDTask ( void );

#endif

/* [] END OF FILE */
