/*******************************************************************************
* File Name: GLCDPWM_2_PM.c
* Version 3.30
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "GLCDPWM_2.h"

static GLCDPWM_2_backupStruct GLCDPWM_2_backup;


/*******************************************************************************
* Function Name: GLCDPWM_2_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  GLCDPWM_2_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void GLCDPWM_2_SaveConfig(void) 
{

    #if(!GLCDPWM_2_UsingFixedFunction)
        #if(!GLCDPWM_2_PWMModeIsCenterAligned)
            GLCDPWM_2_backup.PWMPeriod = GLCDPWM_2_ReadPeriod();
        #endif /* (!GLCDPWM_2_PWMModeIsCenterAligned) */
        GLCDPWM_2_backup.PWMUdb = GLCDPWM_2_ReadCounter();
        #if (GLCDPWM_2_UseStatus)
            GLCDPWM_2_backup.InterruptMaskValue = GLCDPWM_2_STATUS_MASK;
        #endif /* (GLCDPWM_2_UseStatus) */

        #if(GLCDPWM_2_DeadBandMode == GLCDPWM_2__B_PWM__DBM_256_CLOCKS || \
            GLCDPWM_2_DeadBandMode == GLCDPWM_2__B_PWM__DBM_2_4_CLOCKS)
            GLCDPWM_2_backup.PWMdeadBandValue = GLCDPWM_2_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */

        #if(GLCDPWM_2_KillModeMinTime)
             GLCDPWM_2_backup.PWMKillCounterPeriod = GLCDPWM_2_ReadKillTime();
        #endif /* (GLCDPWM_2_KillModeMinTime) */

        #if(GLCDPWM_2_UseControl)
            GLCDPWM_2_backup.PWMControlRegister = GLCDPWM_2_ReadControlRegister();
        #endif /* (GLCDPWM_2_UseControl) */
    #endif  /* (!GLCDPWM_2_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: GLCDPWM_2_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  GLCDPWM_2_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void GLCDPWM_2_RestoreConfig(void) 
{
        #if(!GLCDPWM_2_UsingFixedFunction)
            #if(!GLCDPWM_2_PWMModeIsCenterAligned)
                GLCDPWM_2_WritePeriod(GLCDPWM_2_backup.PWMPeriod);
            #endif /* (!GLCDPWM_2_PWMModeIsCenterAligned) */

            GLCDPWM_2_WriteCounter(GLCDPWM_2_backup.PWMUdb);

            #if (GLCDPWM_2_UseStatus)
                GLCDPWM_2_STATUS_MASK = GLCDPWM_2_backup.InterruptMaskValue;
            #endif /* (GLCDPWM_2_UseStatus) */

            #if(GLCDPWM_2_DeadBandMode == GLCDPWM_2__B_PWM__DBM_256_CLOCKS || \
                GLCDPWM_2_DeadBandMode == GLCDPWM_2__B_PWM__DBM_2_4_CLOCKS)
                GLCDPWM_2_WriteDeadTime(GLCDPWM_2_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */

            #if(GLCDPWM_2_KillModeMinTime)
                GLCDPWM_2_WriteKillTime(GLCDPWM_2_backup.PWMKillCounterPeriod);
            #endif /* (GLCDPWM_2_KillModeMinTime) */

            #if(GLCDPWM_2_UseControl)
                GLCDPWM_2_WriteControlRegister(GLCDPWM_2_backup.PWMControlRegister);
            #endif /* (GLCDPWM_2_UseControl) */
        #endif  /* (!GLCDPWM_2_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: GLCDPWM_2_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves the user configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  GLCDPWM_2_backup.PWMEnableState:  Is modified depending on the enable
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void GLCDPWM_2_Sleep(void) 
{
    #if(GLCDPWM_2_UseControl)
        if(GLCDPWM_2_CTRL_ENABLE == (GLCDPWM_2_CONTROL & GLCDPWM_2_CTRL_ENABLE))
        {
            /*Component is enabled */
            GLCDPWM_2_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            GLCDPWM_2_backup.PWMEnableState = 0u;
        }
    #endif /* (GLCDPWM_2_UseControl) */

    /* Stop component */
    GLCDPWM_2_Stop();

    /* Save registers configuration */
    GLCDPWM_2_SaveConfig();
}


/*******************************************************************************
* Function Name: GLCDPWM_2_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called just after
*  awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  GLCDPWM_2_backup.pwmEnable:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void GLCDPWM_2_Wakeup(void) 
{
     /* Restore registers values */
    GLCDPWM_2_RestoreConfig();

    if(GLCDPWM_2_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        GLCDPWM_2_Enable();
    } /* Do nothing if component's block was disabled before */

}


/* [] END OF FILE */
