/*******************************************************************************
* File Name: GLCD_UPDATE_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "GLCD_UPDATE.h"

/* Check for removal by optimization */
#if !defined(GLCD_UPDATE_Sync_ctrl_reg__REMOVED)

static GLCD_UPDATE_BACKUP_STRUCT  GLCD_UPDATE_backup = {0u};

    
/*******************************************************************************
* Function Name: GLCD_UPDATE_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void GLCD_UPDATE_SaveConfig(void) 
{
    GLCD_UPDATE_backup.controlState = GLCD_UPDATE_Control;
}


/*******************************************************************************
* Function Name: GLCD_UPDATE_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void GLCD_UPDATE_RestoreConfig(void) 
{
     GLCD_UPDATE_Control = GLCD_UPDATE_backup.controlState;
}


/*******************************************************************************
* Function Name: GLCD_UPDATE_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void GLCD_UPDATE_Sleep(void) 
{
    GLCD_UPDATE_SaveConfig();
}


/*******************************************************************************
* Function Name: GLCD_UPDATE_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void GLCD_UPDATE_Wakeup(void)  
{
    GLCD_UPDATE_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
