/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/

/* Include FreeRTOS APIs and defines */
#include <FreeRTOS.h>
#include <task.h>
#include <queue.h>
#include <event_groups.h>

/* Include PSoC system and component APIs and defines */
#include <project.h>

/* Include application function declarations and defines */
#include <GenDef.h>
#include <TaskDelay.h>
#include "GLCD_Task.h"

/********************************************************
* Global Variables
*********************************************************/


/*********************************************
* Requried variables
*********************************************/

/*********************************************
*********************************************/

/* Declaration of NVIC base vector for FreeRTOS exception handling */
#define CORTEX_INTERRUPT_BASE          (16)

/* Declarations of the exception handlers for FreeRTOS */
extern void xPortPendSVHandler(void);
extern void xPortSysTickHandler(void);
extern void vPortSVCHandler(void);

void vApplicationIdleHook( void );

void vAssertCalled ( char * u8FileName, int u8LineNum );

/* Initialize Cortex SVC PendSV and SYSTICK */
void vInitCortexHandle ( void );

// Define CANRxMBox Task Priority
#define vMonitor_Task_PRIORITY				( 3 )

// Function Prototypes

/* Used for vMonitor Task */
void vMonitor_Task ( void *pvParameters );

void vCreateMonitorTask ( void );

int main()
{
	/* Initialize Cortex Handle */
	vInitCortexHandle();
	
	/* Create GLCD Task */
	vCreateGLCDTask();
	
	vCreateMonitorTask();
	
	/* If the task(s) are created successfully, start the OS */
    vTaskStartScheduler();
    
    return 0;
}

/* Initialize Cortex SVC PendSV and SYSTICK */
void vInitCortexHandle ( void )
{
	/* Initialize the OS vectors - make it ready to create the task, below */
    
    /* Handler for Cortex Supervisor Call (SVC, formerly SWI) - address 11 */
    CyIntSetSysVector( CORTEX_INTERRUPT_BASE + SVCall_IRQn,
        (cyisraddress)vPortSVCHandler );
    
    /* Handler for Cortex PendSV Call - address 14 */
	CyIntSetSysVector( CORTEX_INTERRUPT_BASE + PendSV_IRQn,
        (cyisraddress)xPortPendSVHandler );    
    
    /* Handler for Cortex SYSTICK - address 15 */
	CyIntSetSysVector( CORTEX_INTERRUPT_BASE + SysTick_IRQn,
        (cyisraddress)xPortSysTickHandler );
}


/*
 * Function:	vApplicationStackOverflowHook
 *
 * Called if a task exceeds its alloted stack.
 *
 * Requires configCHECK_FOR_STACK_OVERFLOW to be set in FreeRTOSConfig.h.
 *
 * Globals:		None
 *
 * Parameters:	Task handle and name
 *
 * Return:		Never returns - this is a fatal error condition
 */

signed char u8TaskName[configMAX_TASK_NAME_LEN];
UBaseType_t uxHighWaterMark;
void vApplicationStackOverflowHook( xTaskHandle pxTask, signed char *pcTaskName )
{
	uint8 CYXDATA u8TempIndex0=0;
	/* The stack space has been execeeded for a task */
	taskDISABLE_INTERRUPTS();
	
	for(u8TempIndex0=0 ; u8TempIndex0<configMAX_TASK_NAME_LEN ; u8TempIndex0++)
	{
		if(pcTaskName[u8TempIndex0]==0)
			break;
		
		u8TaskName[u8TempIndex0]= pcTaskName[u8TempIndex0];
	}
	
	uxHighWaterMark = uxTaskGetStackHighWaterMark( pxTask );
	
	while( 1 )
    {
        /* Do nothing - this is a placeholder for a breakpoint */
		//LED_2_Write ( LED_2_Read () ^ 0x01 );
		
		CyDelay(500);
    }
}

/*
 * Function:	vApplicationMallocFailedHook
 *
 * Called if a malloc from the FreeRTOS heap fails. This may require more
 * heap (configTOTAL_HEAP_SIZE in FreeRTOSVConfig.h) or a different heap
 * algorithm (heap_?.c in Source\portable\MemMang).
 *
 * Requires configUSE_MALLOC_FAILED_HOOK to be set in FreeRTOSConfig.h.
 *
 * Globals:		None
 *
 * Parameters:	Task handle and name
 *
 * Return:		Never returns - this is a fatal error condition
 */
void vApplicationMallocFailedHook( void )
{
	/* The heap space has been execeeded. */
	taskDISABLE_INTERRUPTS();
	
	while( 1 )
    {
        /* Do nothing - this is a placeholder for a breakpoint */
		//LED_3_Write ( LED_3_Read () ^ 0x01 );
		
		CyDelay(500);
    }
}

uint8 CYXDATA u8FaultFileName[25];

void vAssertCalled ( char * u8FileName, int u8LineNum )
{
	/* The heap space has been execeeded. */
	taskDISABLE_INTERRUPTS();
	
	( void ) u8LineNum;
	
	uint8 CYXDATA u8TempIndex0=0;
	
	for(u8TempIndex0=0 ; u8TempIndex0<25 ; u8TempIndex0++)
	{
		if(u8FileName[u8TempIndex0]==0)
			break;
		
		u8FaultFileName[u8TempIndex0]= u8FileName[u8TempIndex0];
	}
	
	while( 1 )
    {
        /* Do nothing - this is a placeholder for a breakpoint */
		//LED_4_Write ( LED_4_Read () ^ 0x01 );
		
		CyDelay(500);
    }
}

void vCreateMonitorTask ( void )
{
	portBASE_TYPE taskCreated;      /* Return value from xTaskCreate */
	
	/* Create vGLCD_Task */   
	taskCreated = xTaskCreate(
        vMonitor_Task,
        "vMonitor Task",
        configMINIMAL_STACK_SIZE,
        NO_TASK_ARG,          /* Pass the index as a task argument*/
        vMonitor_Task_PRIORITY,
        TASK_HANDLE_UNUSED );
    
    if( taskCreated != pdPASS )
    {
        while(1);
    }
}

extern TaskHandle_t xGLCD_TaskHandle,xGLCD_GEMain_TaskHandle;
UBaseType_t uxHighWaterMark_GLCD,uxHighWaterMark_GLCD_GEM;

void vMonitor_Task ( void *pvParameters )
{
	TickType_t xLastWakeTime; 							/* used for last tick count store */
	
	const TickType_t xTaskDelay = Monitor_TASK_Delay; 	/* used for the delay between task loop */
	
	/* Just to stop compiler warnings. */
	( void ) pvParameters;
	
	// Initialise the xLastWakeTime variable with the current time.
    xLastWakeTime = xTaskGetTickCount();
	
	for(;;)
	{
		// Wait for the next cycle.
		vTaskDelayUntil( &xLastWakeTime, xTaskDelay );
		
		uxHighWaterMark_GLCD = uxTaskGetStackHighWaterMark( xGLCD_TaskHandle );
		uxHighWaterMark_GLCD_GEM = uxTaskGetStackHighWaterMark( xGLCD_GEMain_TaskHandle );
		
		LED_1_Write ( LED_1_Read () ^ 0x01 );
		
	} /* for(;;) */
}

/* [] END OF FILE */
